@@ -7,7 +7,7 @@ var usersRightsWindowHeight = 179;
 var usersRightsWindowWidth = 450;
 
 var Contact = {
-    currentAddressBook: null,
+    currentAddressBook: "/personal",
     currentContact: null,
     deleteContactsRequestCount: null
 };
@@ -55,8 +55,6 @@ function openContactsFolder(contactsFolder, reload, idx) {
             var contactsList = $("contactsList");
             if (contactsList)
                 selection = contactsList.getSelectedRowsId();
-            //        else
-            //           window.alert("no contactsList");
         }
         else
             selection = null;
@@ -70,18 +68,6 @@ function openContactsFolder(contactsFolder, reload, idx) {
     }
 }
 
-function openContactsFolderAtIndex(element) {
-    var idx = element.getAttribute("idx");
-    var url = URLForFolderID(Contact.currentAddressBook) + "/view?noframe=1&idx=" + idx;
-
-    if (document.contactsListAjaxRequest) {
-        document.contactsListAjaxRequest.aborted = true;
-        document.contactsListAjaxRequest.abort();
-    }
-    document.contactsListAjaxRequest
-        = triggerAjaxRequest(url, contactsListCallback);
-}
-
 function contactsListCallback(http) {
     if (http.readyState == 4) {
         if (http.status == 200) {
@@ -89,32 +75,78 @@ function contactsListCallback(http) {
             
             var div = $("contactsListContent");
             var table = $("contactsList");
-            if (table) {
-                // Update table
-                var data = http.responseText;
-                var html = data.replace(/^(.*\n)*.*(<table(.*\n)*)$/, "$2");
-                var tbody = table.tBodies[0];
-                var tmp = document.createElement('div');
-                $(tmp).update(html);
-                table.replaceChild($(tmp).select("table tbody")[0], tbody);
-            }
-            else {
-                // Add table
-                div.update(http.responseText);
-                table = $("contactsList");
-                table.multiselect = true;
-                table.observe("mousedown", onContactSelectionChange);
-                configureSortableTableHeaders(table);
-                TableKit.Resizable.init(table, {'trueResize' : true, 'keepWidth' : true});
+            var tbody = table.tBodies[0];
+            var rows = tbody.getElementsByTagName("TR");
+            var data = [];
+            if (http.responseText.length > 0)
+                data = http.responseText.evalJSON(true);
+
+            tbody.deselectAll();
+
+            div.scrollTop = 0;            
+            if (data.length > 0) {
+                // Replace existing rows
+                for (var i = 0; i < data.length && i < rows.length; i++) {
+                    var contact = data[i];
+                    var row = rows[i];
+                    row.className = contact["c_component"];
+                    row.setAttribute("id", contact["c_name"]);
+                    row.setAttribute("categories", contact["c_categories"]);
+                    row.setAttribute("contactname", contact["c_cn"]);
+                    var cells = row.getElementsByTagName("TD");
+                    $(cells[0]).update(contact["c_cn"]);
+                    $(cells[1]).update(contact["c_mail"]);
+                    $(cells[2]).update(contact["c_screenname"]);
+                    $(cells[3]).update(contact["c_o"]);
+                    $(cells[4]).update(contact["c_telephonenumber"]);
+                }
+
+                // Add extra rows
+                for (var j = i; j < data.length; j++) {
+                    var contact = data[j];
+                    var row = createElement("tr",
+                                            contact["c_name"],
+                                            contact["c_component"],
+                                            null,
+                                            { categories: contact["c_categories"],
+                                              contactname: contact["c_cn"] },
+                                            tbody);
+                    
+                    var cell = createElement("td",
+                                             null,
+                                             ( "displayName" ),
+                                             null,
+                                             null,
+                                             row);
+                    cell.appendChild(document.createTextNode(contact["c_cn"]));
+
+                    cell = document.createElement("td");
+                    row.appendChild(cell);
+                    if (contact["c_mail"])
+                        cell.appendChild(document.createTextNode(contact["c_mail"]));
+
+                    cell = document.createElement("td");
+                    row.appendChild(cell);
+                    if (contact["c_screenname"])
+                        cell.appendChild(document.createTextNode(contact["c_screenname"]));
+
+                    cell = document.createElement("td");
+                    row.appendChild(cell);
+                    if (contact["c_o"])
+                        cell.appendChild(document.createTextNode(contact["c_o"]));
+
+                    cell = document.createElement("td");
+                    row.appendChild(cell);
+                    if (contact["c_telephonenumber"])
+                        cell.appendChild(document.createTextNode(contact["c_telephonenumber"]));
+                }
+
                 configureDraggables();
             }
-            var rows = table.tBodies[0].rows;
-            for (var i = 0; i < rows.length; i++) {
-                var row = $(rows[i]);
-                row.observe("mousedown", onRowClick);
-                row.observe("dblclick", onContactRowDblClick);
-                row.observe("selectstart", listRowMouseDownHandler);
-                row.observe("contextmenu", onContactContextMenu);
+
+            // Remove unnecessary rows
+            for (i = rows.length - 1; i >= data.length; i--) {
+                tbody.removeChild(rows[i]);
             }
             
             if (sorting["attribute"] && sorting["attribute"].length > 0) {
@@ -141,26 +173,30 @@ function contactsListCallback(http) {
                     var sortImage = createElement("img", "messageSortImage", "sortImage");
                     sortHeader.insertBefore(sortImage, sortHeader.firstChild);
                     if (sorting["ascending"])
-                        sortImage.src = ResourcesURL + "/arrow-down.png";
-                    else
                         sortImage.src = ResourcesURL + "/arrow-up.png";
+                    else
+                        sortImage.src = ResourcesURL + "/arrow-down.png";
                 }
             }
-            
-            var selected = http.callbackData;
-            if (selected) {
-                for (var i = 0; i < selected.length; i++) {
-                    var row = $(selected[i]);
+
+            // Restore selection and scroll to first selected node
+            tbody.refreshSelectionByIds();
+            var selection = http.callbackData;
+            if (selection) {
+                for (var i = 0; i < selection.length; i++) {
+                    var row = $(selection[i]);
                     if (row) {
                         var rowPosition = row.rowIndex * row.getHeight();
                         if (div.getHeight() < rowPosition)
                             div.scrollTop = rowPosition; // scroll to selected contact
-                        row.selectElement();
+                        break;
                     }
                 }
             }
+            
         }
         else {
+            // No more access to this address book; empty the list
             var table = $("contactsList");
             if (table) {
                 var sortImages = $(table.tHead).select(".sortImage");
@@ -179,11 +215,21 @@ function contactsListCallback(http) {
 }
 
 function onContactContextMenu(event) {
+    var target = Event.element(event);
+    var contact = target.up('TR');
     var contactsList = $("contactsList");
-    var menu = $("contactMenu");
-    menu.observe("hideMenu", onContactContextMenuHide);
-    if (contactsList)
-        popupMenu(event, "contactMenu", contactsList.getSelectedRows());
+    var contacts = contactsList.getSelectedRows();
+
+    if (contacts.indexOf(contact) < 0) {
+        onRowClick(event, target);
+        contacts = contactsList.getSelectedRows();
+    }
+
+    if (contactsList) {
+        var menu = $("contactMenu");
+        menu.observe("contextmenu:hide", onContactContextMenuHide);
+        popupMenu(event, "contactMenu", contacts);
+    }
 }
 
 function onContactContextMenuHide(event) {
@@ -199,6 +245,8 @@ function onContactContextMenuHide(event) {
             $(nodes[i]).selectElement();
         topNode.menuSelectedRows = null;
     }
+
+    this.stopObserving("contextmenu:hide", onContactContextMenuHide);
 }
 
 function onFolderMenuHide(event) {
@@ -225,7 +273,7 @@ function _onContactMenuAction(folderItem, action, refresh) {
 
         for (var i = 0; i < contactIds.length; i++) {
             if (contactIds[i].endsWith ("vlf")) {
-                alert (_("Lists can't be moved or copied."));
+                showAlertDialog(_("Lists can't be moved or copied."));
                 return false;
             }
         }
@@ -348,7 +396,8 @@ function moveTo(uri) {
 
 /* contact menu entries */
 function onContactRowDblClick(event) {
-    var cname = this.getAttribute('id');
+    var t = getTarget(event);
+    var cname = t.parentNode.getAttribute('id');
 
     openContactWindow(URLForFolderID(Contact.currentAddressBook)
                       + "/" + cname + "/edit", cname);
@@ -357,7 +406,13 @@ function onContactRowDblClick(event) {
 }
 
 function onContactSelectionChange(event) {
-    var rows = this.getSelectedRowsId();
+    if (event) {
+        // Update rows selection
+        var t = getTarget(event);
+        onRowClick(event, t);
+    }
+
+    var rows = this.parentNode.getSelectedRowsId();
   
     if (rows.length == 1) {
         var node = $(rows[0]);
@@ -442,11 +497,13 @@ function onToolbarDeleteSelectedContacts(event) {
 }
 
 function onToolbarDeleteSelectedContactsConfirm(dialogId) {
+    disposeDialog();
     var contactsList = $('contactsList');
     var rows = contactsList.getSelectedRowsId();
     for (var i = 0; i < rows.length; i++) {
-        // hide row?
-        $(rows[i]).hide();
+        var row = $(rows[i]);
+        row.deselect();
+        row.hide();
         delete cachedContacts[Contact.currentAddressBook + "/" + rows[i]];
         var urlstr = (URLForFolderID(Contact.currentAddressBook) + "/"
                       + rows[i] + "/delete");
@@ -454,8 +511,6 @@ function onToolbarDeleteSelectedContactsConfirm(dialogId) {
         triggerAjaxRequest(urlstr, onContactDeleteEventCallback,
                            rows[i]);
     }
-
-    disposeDialog();
 }
 
 function onContactDeleteEventCallback(http) {
@@ -477,7 +532,6 @@ function onContactDeleteEventCallback(http) {
                     loadContact(Contact.currentContact);
                 }
             }
-            row.deselect();
             row.parentNode.removeChild(row);
         }
         else if (parseInt(http.status) == 403) {
@@ -534,7 +588,7 @@ function newContact(sender) {
 function newList(sender) {
     var li = $(Contact.currentAddressBook);
     if (li.hasClassName("remote"))
-      alert(_("You cannot create a list in a shared address book."));
+      showAlertDialog(_("You cannot create a list in a shared address book."));
     else
       openContactWindow(URLForFolderID(Contact.currentAddressBook) + "/newlist");
 
@@ -543,14 +597,16 @@ function newList(sender) {
 
 function onFolderSelectionChange(event) {
     var folderList = $("contactFolders");
-    var nodes = folderList.getSelectedNodes();
 
     if (event) {
         var node = getTarget(event);
         if (node.tagName == 'UL')
             return;
+        // Update rows selection
+        onRowClick(event, node);
     }
 
+    var nodes = folderList.getSelectedNodes();
     $("contactView").update();
     Contact.currentContact = null;
 
@@ -586,7 +642,7 @@ function onConfirmContactSelection(event) {
                              currentAddressBookName, cid);
         }
         else {
-          var cname = '' + rows[i].getAttribute("contactname");
+          var cname = '' + rows[i].readAttribute("contactname");
           var email = '' + rows[i].cells[1].innerHTML;
 		
           window.opener.addContact(tag, currentAddressBookName + '/' + cname,
@@ -627,7 +683,7 @@ function refreshContacts(cname) {
 }
 
 function onAddressBookNew(event) {
-    showPromptDialog(_("New addressbook..."), _("Name of the Address Book"), onAddressBookNewConfirm);
+    showPromptDialog(_("New Addressbook..."), _("Name of the Address Book"), onAddressBookNewConfirm);
     preventDefault(event);
 }
 
@@ -672,7 +728,6 @@ function appendAddressBook(name, folder) {
         li.appendChild(document.createTextNode(name
                                                .replace("&lt;", "<", "g")
                                                .replace("&gt;", ">", "g")));
-        setEventsOnAddressBook(li);
         updateAddressBooksMenus();
         configureDroppables();
     }
@@ -890,19 +945,16 @@ function configureAbToolbar() {
 function configureAddressBooks() {
     var contactFolders = $("contactFolders");
     if (contactFolders) {
-        contactFolders.observe("mousedown", listRowMouseDownHandler);
-        contactFolders.observe("click", onFolderSelectionChange);
+        contactFolders.on("mousedown", onFolderSelectionChange);
+        contactFolders.on("dblclick", onAddressBookModify);
+        contactFolders.on("selectstart", listRowMouseDownHandler);
         contactFolders.attachMenu("contactFoldersMenu");
-        var lis = contactFolders.childNodesWithTag("li");
-        for (var i = 0; i < lis.length; i++)
-            setEventsOnAddressBook(lis[i]);
     
         lookupDeniedFolders();
         configureDroppables();
 
-        var personalFolder = $("/personal");
-        personalFolder.selectElement();
-        openContactsFolder("/personal");
+        // Select initial addressbook
+        $(Contact.currentAddressBook).selectElement();
     }
 }
 
@@ -963,23 +1015,10 @@ function updateAddressBooksMenus() {
     }
 }
   
-function setEventsOnAddressBook(folder) {
-    var node = $(folder);
-
-    node.observe("mousedown", listRowMouseDownHandler);
-    node.observe("click", onRowClick);
-    if (node.readAttribute("owner") != "nobody") {
-        node.observe("dblclick", onAddressBookModify);
-    }
-}
-
 function onAddressBookModify(event) {
     var folders = $("contactFolders");
     var selected = folders.getSelectedNodes()[0];
-    if (selected.getAttribute("owner") == "nobody") {
-        showAlertDialog(_("Unable to rename that folder!"));
-    }
-    else {
+    if (selected.getAttribute("owner") != "nobody") {
         var currentName = selected.innerHTML.unescapeHTML();
         showPromptDialog(_("Properties"),
                          _("Address Book Name"),
@@ -1206,7 +1245,7 @@ function onDocumentKeydown(event) {
                         viewPort.scrollTop += rowBottom - divBottom;
                     else if (rowScrollOffset.top > rowPosition.top)
                         viewPort.scrollTop -= rowScrollOffset.top - rowPosition.top;
-					
+                    
                     // Select and load the next message
                     nextRow.selectElement();
                     loadContact(nextRow.readAttribute("id"));
@@ -1249,25 +1288,30 @@ function initContacts(event) {
     Event.observe(document, "keydown", onDocumentKeydown);
     
     configureAddressBooks();
+    configureDraggables();
     updateAddressBooksMenus();
 
     var table = $("contactsList");
     if (table) {
-        // Initialize contacts table
+        // Initialize event delegation on contacts table
         table.multiselect = true;
-        table.observe("mousedown", onContactSelectionChange);
+        var tbody = $(table.tBodies[0]);
+        tbody.on("click", onContactSelectionChange);
+        tbody.on("dblclick", onContactRowDblClick);
+        tbody.on("selectstart", listRowMouseDownHandler);
+        tbody.on("contextmenu", onContactContextMenu);
         configureSortableTableHeaders(table);
         TableKit.Resizable.init(table, {'trueResize' : true, 'keepWidth' : true});
+    
+        resetCategoriesMenu();
     }
-        
+    
     onWindowResize.defer();
     Event.observe(window, "resize", onWindowResize);
     
     // Default sort options
     sorting["attribute"] = "c_cn";
     sorting["ascending"] = true;
-
-    resetCategoriesMenu();
 }
 
 function resetCategoriesMenu() {
@@ -1286,8 +1330,7 @@ function resetCategoriesMenu() {
             var catName = UserDefaults["SOGoContactsCategories"][i];
             if (catName.length > 0) {
                 var menuLI = createElement("li");
-                var bound = onCategoriesMenuItemClick.bindAsEventListener(menuLI);
-                menuLI.observe("click", bound);
+                menuLI.observe("click", onCategoriesMenuItemClick);
                 menuLI.category = catName;
                 menuLI.appendChild(document.createTextNode(catName));
                 menuUL.appendChild(menuLI);
@@ -1306,7 +1349,7 @@ function onCategoriesMenuPrepareVisibility() {
     if (contactsList) {
         var rows = contactsList.getSelectedRows();
         if (rows.length > 0) {
-            var catList = rows[0].getAttribute("categories");
+            var catList = rows[0].readAttribute("categories");
             var catsArray;
             if (catList && catList.length > 0) {
                 catsArray = catList.split(",");
@@ -1314,7 +1357,6 @@ function onCategoriesMenuPrepareVisibility() {
             else {
                 catsArray = [];
             }
-
             var menu = $("categoriesMenu");
             var ul = menu.down("ul");
             var listElements = ul.select("li");
@@ -1338,12 +1380,12 @@ function onCategoriesMenuItemClick() {
     var contactsList = $("contactsList");
     var rowIds = contactsList.getSelectedRowsId();
     if (rowIds.length > 0) {
-        log("coucou...");
         for (var i = 0; i < rowIds.length; i++) {
             var url = (URLForFolderID(Contact.currentAddressBook)
                        + "/" + rowIds[i] + "/" + method);
-            url += "?category=" + escape(this.category);
-            triggerAjaxRequest(url);
+            url += "?category=" + encodeURIComponent(this.category);
+            triggerAjaxRequest(url, onCategoriesMenuItemCallback,
+                               { 'addressBook' : Contact.currentAddressBook, 'id' : rowIds[i] });
             if (set) {
                 setCategoryOnNode($(rowIds[i]), this.category);
             }
@@ -1354,6 +1396,21 @@ function onCategoriesMenuItemClick() {
     }
 }
 
+function onCategoriesMenuItemCallback(http) {
+    if (http.readyState == 4)
+        if (isHttpStatus204(http.status)) {
+            var contact = http.callbackData;
+            if (cachedContacts[contact.addressBook + "/" + contact.id])
+                delete cachedContacts[contact.addressBook + "/" + contact.id];
+            if (contact.addressBook == Contact.currentAddressBook
+                && contact.id == Contact.currentContact)
+                loadContact(Contact.currentContact);
+        }
+        else if (parseInt(http.status) == 403) {
+            log("onCategoriesMenuItemCallback failed: error " + http.status + " (" + http.responseText + ")");
+        }
+}
+
 function setCategoryOnNode(contactNode, category) {
     var catList = contactNode.getAttribute("categories");
     var catsArray = catList.split(",");
@@ -1424,12 +1481,19 @@ function startDragging (itm, e) {
     var handle = $("dragDropVisual");
     var contacts = $('contactsList').getSelectedRowsId();
     var count = contacts.length;
+    var row = target.up('TR');
     
-    handle.show();
-    handle.update (count);
-    if (e.shiftKey || currentFolderIsRemote ()) {
-      handle.addClassName ("copy");
+    if (count == 0 || contacts.indexOf(row.id) < 0) {
+        onRowClick(e, target);
+        contacts = $("contactsList").getSelectedRowsId();
+        count = contacts.length;
     }
+
+    handle.update (count);
+    if (e.shiftKey || currentFolderIsRemote()) {
+      handle.addClassName("copy");
+    }
+    handle.show();
 }
 
 function whileDragging (itm, e) {
@@ -1462,7 +1526,7 @@ function dropSelectedContacts (action, toId) {
         var contactIds = $('contactsList').getSelectedRowsId();
         for (var i = 0; i < contactIds.length; i++) {
             if (contactIds[i].endsWith ("vlf")) {
-                alert (_("Lists can't be moved or copied."));
+                showAlertDialog(_("Lists can't be moved or copied."));
                 return false;
             }
         }
