@@ -240,7 +240,6 @@ function createAttachment(node, list) {
     var attachment = createElement("li", null, null, { node: node }, null, list);
     createElement("img", null, null, { src: ResourcesURL + "/attachment.gif" },
                   null, attachment);
-    attachment.observe("click", onRowClick);
 
     var filename = node.value;
     var separator;
@@ -251,6 +250,7 @@ function createAttachment(node, list) {
     var fileArray = filename.split(separator);
     var attachmentName = document.createTextNode(fileArray[fileArray.length-1]);
     attachment.appendChild(attachmentName);
+    attachment.writeAttribute("title", fileArray[fileArray.length-1]);
 }
 
 function clickedEditorSave() {
@@ -339,21 +339,20 @@ function onTextMouseDown(event) {
     }
 }
 
-function initTabIndex(addressList, subjectField, msgArea) {
+function initAddresses() {
+    var addressList = $("addressList");
     var i = 1;
     addressList.select("input.textField").each(function (input) {
             if (!input.readAttribute("readonly")) {
-                input.writeAttribute("tabindex", i++);
                 input.addInterface(SOGoAutoCompletionInterface);
                 input.uidField = "c_name";
-                input.observe("focus", addressFieldGotFocus.bind(input));
-                input.observe("blur", addressFieldLostFocus.bind(input));
-                input.observe("autocompletion:changedlist", expandContactList);
+                input.on("focus", addressFieldGotFocus.bind(input));
+                input.on("blur", addressFieldLostFocus.bind(input));
+                input.on("autocompletion:changedlist", expandContactList);
+                input.on("autocompletion:changed", addressFieldChanged.bind(input));
                 //input.onListAdded = expandContactList;
             }
         });
-    subjectField.writeAttribute("tabindex", i++);
-    msgArea.writeAttribute("tabindex", i);
 }
 
 function initMailEditor() {
@@ -362,16 +361,14 @@ function initMailEditor() {
 
     var list = $("attachments");
     if (!list) return;
-    $(list).attachMenu("attachmentsMenu");
+    list.multiselect = true;
+    list.on("click", onRowClick);
+    list.attachMenu("attachmentsMenu");
     var elements = $(list).childNodesWithTag("li");
-    for (var i = 0; i < elements.length; i++)
-        elements[i].observe("click", onRowClick);
-
-    var listContent = $("attachments").childNodesWithTag("li");
-    if (listContent.length > 0)
+    if (elements.length > 0)
         $("attachmentsArea").setStyle({ display: "block" });
 
-     var textarea = $("text");
+    var textarea = $("text");
   
     var textContent = textarea.getValue();
     if (hasSignature()) {
@@ -392,8 +389,7 @@ function initMailEditor() {
             textarea.observe(ieEvents[i], onTextIEUpdateCursorPos, false);
     }
 
-    var subjectField = $$("div#subjectRow input").first();
-    initTabIndex($("addressList"), subjectField, textarea);
+    initAddresses();
 
     var focusField = (mailIsReply ? textarea : $("addr_0"));
     focusField.focus();
@@ -409,7 +405,7 @@ function initMailEditor() {
                                'BulletedList', '-', 'Link', 'Unlink', 'Image', 
                                'JustifyLeft','JustifyCenter','JustifyRight',
                                'JustifyBlock','Font','FontSize','-','TextColor',
-                               'BGColor']
+                               'BGColor','-','SpellChecker']
                              ],
                              language : localeCode,
 			     scayt_sLang : localeCode
@@ -553,14 +549,11 @@ function onMenuSetPriority(event) {
 }
 
 function onSelectAllAttachments() {
-    var list = $("attachments");
-    var nodes = list.childNodesWithTag("li");
-    for (var i = 0; i < nodes.length; i++)
-        nodes[i].selectElement();
+    $("attachments").selectAll();
 }
 
 function onSelectOptions(event) {
-    if (event.button == 0 || (isSafari() && event.button == 1)) {
+    if (event.button == 0 || (isWebKit() && event.button == 1)) {
         var node = getTarget(event);
         if (node.tagName != 'A')
             node = $(node).up("A");
