@@ -37,15 +37,17 @@ function savePreferences(sender) {
     }
 
     if ($("enableForward") && $("enableForward").checked) {
-        if (!emailRE.test($("forwardAddress").value)) {
-            alert(_("Please specify an address to which you want to forward your messages."));
-            sendForm = false;
-        }
+        var addresses = $("forwardAddress").value.split(",");
+        for (var i = 0; i < addresses.length && sendForm; i++)
+            if (!emailRE.test(addresses[i].strip())) {
+                alert(_("Please specify an address to which you want to forward your messages."));
+                sendForm = false;
+            }
     }
 
     if (isSieveScriptsEnabled) {
         var jsonFilters = prototypeIfyFilters();
-        $("sieveFilters").setValue(jsonFilters.toJSON());
+        $("sieveFilters").setValue(Object.toJSON(jsonFilters));
     }
 
     saveMailAccounts();
@@ -85,8 +87,8 @@ function prototypeIfyFilters() {
 function _setupEvents() {
     var widgets = [ "timezone", "shortDateFormat", "longDateFormat",
                     "timeFormat", "weekStartDay", "dayStartTime", "dayEndTime",
-                    "firstWeek", "messageCheck", "subscribedFoldersOnly",
-                    "language" ];
+                    "firstWeek", "messageCheck", "sortByThreads", 
+                    "subscribedFoldersOnly", "language" ];
     for (var i = 0; i < widgets.length; i++) {
         var widget = $(widgets[i]);
         if (widget) {
@@ -94,12 +96,17 @@ function _setupEvents() {
         }
     }
 
+
+    // We check for non-null elements as replyPlacementList and composeMessagesType
+    // might not be present if ModulesConstraints disable those elements
+    if ($("replyPlacementList"))
+    	$("replyPlacementList").observe ("change", onReplyPlacementListChange);
+    
+    if ($("composeMessagesType"))
+    	$("composeMessagesType").observe ("change", onComposeMessagesTypeChange);
+
     // Note: we also monitor changes to the calendar categories.
     // See functions endEditable and onColorPickerChoice.
-
-    $("replyPlacementList").observe ("change", onReplyPlacementListChange);
-    $("composeMessagesType").observe ("change", onComposeMessagesTypeChange);
-
     var valueInputs = [ "calendarCategoriesValue", "calendarCategoriesValue" ];
     for (var i = 0; i < valueInputs.length; i++) {
         var valueInput = $(valueInputs[i]);
@@ -220,9 +227,9 @@ function appendSieveFilterRow(filterTable, number, filter) {
 
     var activeColumn = createElement("td", null, "activeColumn");
     var cb = createElement("input", null, "checkBox",
-                           { checked: filter.active,
-                             type: "checkbox" },
+                           { type: "checkbox" },
                            null, activeColumn);
+    cb.checked = filter.active;
     var bound = onScriptActiveCheck.bindAsEventListener(cb);
     cb.observe("click", bound);
     row.appendChild(activeColumn);
@@ -665,7 +672,7 @@ function displayAccountSignature(mailAccount) {
     var identity = (mailAccount["identities"]
                     ? mailAccount["identities"][0]
                     : {} );
-    var value = identity["signature"];
+    var value = identity["signature"].stripTags().unescapeHTML().replace(/^[ \n\r]*/, "");
     if (value && value.length > 0) {
         if (value.length < 30) {
             actSignatureValue = value;
@@ -680,7 +687,7 @@ function displayAccountSignature(mailAccount) {
     while (actSignature.firstChild) {
         actSignature.removeChild(actSignature.firstChild);
     }
-    actSignature.appendChild(document.createTextNode(actSignatureValue));
+    actSignature.update(actSignatureValue);
 }
 
 function createMailAccount() {
@@ -749,14 +756,23 @@ function saveMailAccounts() {
     /* This removal enables us to avoid a few warning from SOPE for the inputs
      that were created dynamically. */
     var editor = $("mailAccountEditor");
-    editor.parentNode.removeChild(editor);
+    
+    // Could be null if ModuleConstraints disables email access
+    if (editor)
+    	editor.parentNode.removeChild(editor);
 
     compactMailAccounts();
     var mailAccountsJSON = $("mailAccountsJSON");
-    mailAccountsJSON.value = mailAccounts.toJSON();
+ 
+    if (mailAccountsJSON)
+        mailAccountsJSON.value = Object.toJSON(mailAccounts);
 }
 
 function compactMailAccounts() {
+
+    if (!mailAccounts)
+        return;
+
     for (var i = 1; i < mailAccounts.length; i++) {
         var account = mailAccounts[i];
         var encryption = account["encryption"];
@@ -930,7 +946,7 @@ function serializeContactsCategories() {
         values.push(td.allTextContent());
     }
 
-    $("contactsCategoriesValue").value = values.toJSON();
+    $("contactsCategoriesValue").value = Object.toJSON(values);
 }
 
 /* / contact categories */
