@@ -449,16 +449,17 @@ function isSafari3() {
     return (navigator.appVersion.indexOf("Version") > -1);
 }
 
-function isSafari() {
+function isWebKit() {
     //var agt = navigator.userAgent.toLowerCase();
     //var is_safari = ((agt.indexOf('safari')!=-1)&&(agt.indexOf('mac')!=-1))?true:false;
-
-    return (navigator.vendor == "Apple Computer, Inc.") || (navigator.userAgent.toLowerCase().indexOf('konqueror') != -1);
+    return (navigator.vendor == "Apple Computer, Inc.") ||
+        (navigator.userAgent.toLowerCase().indexOf('konqueror') != -1) ||
+        (navigator.userAgent.indexOf('AppleWebKit') != -1);
 }
 
 function isHttpStatus204(status) {
     return (status == 204 ||                                  // Firefox
-            (isSafari() && typeof(status) == 'undefined') ||  // Safari
+            (isWebKit() && typeof(status) == 'undefined') ||  // Safari
             status == 1223);                                  // IE
 }
 
@@ -498,7 +499,7 @@ function refreshOpener() {
 
 function eventIsLeftClick(event) {
     var isLeftClick = true;
-    if (isMac() && isSafari()) {
+    if (isMac() && isWebKit()) {
         if (event.ctrlKey == 1) {
             // Control-click is equivalent to right-click under Mac OS X
             isLeftClick = false;
@@ -554,6 +555,7 @@ function onRowClick(event, target) {
     if (node.tagName == 'TD') {
         node = node.parentNode; // select TR
     }
+
     if (node.tagName == 'TR') {
         var head = $(node).up('table').down('thead');
         rowIndex = node.rowIndex;
@@ -576,7 +578,10 @@ function onRowClick(event, target) {
             // No parent; stop here
             return true;
     }
-
+    else
+        // Not a list; stop here
+        return true;
+    
     var initialSelection = $(node.parentNode).getSelectedNodesId();
     if (initialSelection && initialSelection.length > 0
         && initialSelection.indexOf(node.id) >= 0
@@ -601,14 +606,6 @@ function onRowClick(event, target) {
         // Single line selection
         $(node.parentNode).deselectAll();
         $(node).selectElement();
-
-        if (initialSelection != $(node.parentNode).getSelectedNodesId()) {
-            // Selection has changed; fire mousedown event
-            var parentNode = node.parentNode;
-            if (parentNode.tagName == 'TBODY')
-                parentNode = parentNode.parentNode;
-            parentNode.fire("mousedown");
-        }
     }
     if (rowIndex != null) {
 	lastClickedRow = rowIndex;
@@ -665,7 +662,7 @@ function popupMenu(event, menuId, target) {
 
         document.currentPopupMenu = popup;
 
-        $(document.body).observe("click", onBodyClickMenuHandler);
+        $(document.body).observe("mousedown", onBodyClickMenuHandler);
     }
 }
 
@@ -688,9 +685,8 @@ function getParentMenu(node) {
 }
 
 function onBodyClickMenuHandler(event) {
+    this.stopObserving(event.type);
     hideMenu(document.currentPopupMenu);
-    document.body.stopObserving("click", onBodyClickMenuHandler);
-    document.body.stopObserving("mouseup", onBodyClickMenuHandler);
     document.currentPopupMenu = null;
 
     if (event)
@@ -733,7 +729,7 @@ function hideMenu(menuNode) {
         menuNode.parentMenu = null;
     }
 
-    $(menuNode).fire("mousedown");
+    Event.fire(menuNode, "contextmenu:hide");
 }
 
 function onMenuEntryClick(event) {
@@ -894,10 +890,13 @@ function popupSubmenu(event) {
                 menuTop = 0;
         }
 
-        var menuLeft = (parentNode.offsetLeft + parentNode.offsetWidth - 3);
-        if (window.width()
-            < (menuLeft + submenuNode.offsetWidth))
-            menuLeft = parentNode.offsetLeft - submenuNode.offsetWidth + 3;
+        var menuLeft = this.offsetLeft + this.offsetWidth;
+        menuLeft = $(this.parentNode.parentNode).positionedOffset()[0]
+            + $(this.parentNode).positionedOffset()[0]
+            + $(this).getWidth();
+        if (menuLeft + submenuNode.getWidth() > window.width())
+            // Keep the submenu inside the viewport
+            menuLeft = window.width() - submenuNode.getWidth();
 
         this.mouseInside = true;
         this.observe("mouseover", onMouseEnteredSubmenu);
@@ -957,9 +956,6 @@ function setSearchCriteria(event) {
     var searchValue = $("searchValue");
     var searchCriteria = $("searchCriteria");
 
-    if (searchValue.ghostPhrase == searchValue.value)
-        searchValue.value = this.innerHTML;
-
     searchValue.ghostPhrase = this.innerHTML;
     searchCriteria.value = this.getAttribute('id');
 
@@ -967,6 +963,8 @@ function setSearchCriteria(event) {
         this.parentNode.chosenNode.removeClassName("_chosen");
     this.addClassName("_chosen");
 
+    searchValue.focus();
+
     if (this.parentNode.chosenNode != this) {
         searchValue.lastSearch = "";
         this.parentNode.chosenNode = this;
@@ -1011,8 +1009,7 @@ function onSearchFocus(event) {
     } else {
         this.selectElement();
     }
-
-    this.setStyle({ color: "#535D6D" });
+    this.setStyle({ color: "#262B33" });
 }
 
 function onSearchBlur(event) {
@@ -1032,7 +1029,7 @@ function onSearchBlur(event) {
         this.setStyle({ color: "#909090" });
     } else {
         this.setAttribute("modified", "yes");
-        this.setStyle({ color: "#535D6D" });
+        this.setStyle({ color: "#262B33" });
     }
 }
 
@@ -1351,16 +1348,12 @@ function initMenus() {
 
 function initMenu(menuDIV, callbacks) {
     var uls = menuDIV.childNodesWithTag("ul");
-    for (var i = 0; i < uls.length; i++) {
+    for (var i = 0, j = 0; i < uls.length; i++) {
         var lis = $(uls[i]).childNodesWithTag("li");
-        for (var j = 0; j < lis.length; j++) {
-            var node = $(lis[j]);
-            node.observe("mousedown", listRowMouseDownHandler, false);
-            var callback;
-            if (i > 0)
-                callback = callbacks[i+j+1];
-            else
-                callback = callbacks[i+j];
+        for (var k = 0; k < lis.length; k++, j++) {
+            var node = $(lis[k]);
+            node.on("mousedown", listRowMouseDownHandler);
+            var callback = callback = callbacks[j];
             if (callback) {
                 if (typeof(callback) == "string") {
                     if (callback == "-")
@@ -1368,13 +1361,12 @@ function initMenu(menuDIV, callbacks) {
                     else {
                         node.submenu = callback;
                         node.addClassName("submenu");
-                        node.observe("mouseover", popupSubmenu);
+                        node.on("mouseover", popupSubmenu);
                     }
                 }
                 else {
-                    node.observe("mouseup", onBodyClickMenuHandler);
                     node.menuCallback = callback;
-                    node.observe("click", onMenuClickHandler);
+		    node.on("mousedown", onMenuClickHandler);
                 }
             }
             else
@@ -1780,9 +1772,13 @@ function createDialog(id, title, legend, content, positionClass) {
         var titleh3 = createElement("h3", null, null, null, null, subdiv);
         titleh3.appendChild(document.createTextNode(title));
     }
-    if (legend && legend.length > 0) {
-        var legendP = createElement("p", null, null, null, null, subdiv);
-        legendP.appendChild(document.createTextNode(legend));
+    if (legend) {
+        if (Object.isElement(legend))
+            subdiv.appendChild(legend);
+        else if (legend.length > 0) {
+            var legendP = createElement("p", null, null, null, null, subdiv);
+            legendP.appendChild(document.createTextNode(legend));
+        }
     }
     if (content)
         subdiv.appendChild(content);
@@ -1798,19 +1794,18 @@ function createButton(id, caption, action) {
         span.appendChild(document.createTextNode(caption));
     }
     if (action)
-        newButton.observe("click", action);
+        newButton.on("click", action);
 
     return newButton;
 }
 
 function showAlertDialog(label) {
     var div = $("bgDialogDiv");
-    if (div && div.visible()) {
+    if (div && div.visible() && div.getOpacity() > 0) {
         dialogsStack.push(label);
     }
-    else {
+    else
         _showAlertDialog(label);
-    }
 }
 
 function _showAlertDialog(label) {
@@ -1831,13 +1826,23 @@ function _showAlertDialog(label) {
         document.body.appendChild(dialog);
         dialogs[label] = dialog;
     }
-    dialog.show();
+    dialog.appear({ duration: 0.2 });
 }
 
 function showConfirmDialog(title, label, callbackYes, callbackNo) {
-    var dialog = dialogs[title+label];
+    var key = title;
+    if (Object.isElement(label)) key += label.allTextContent();
+    else key += label;
+    var dialog = dialogs[key];
     if (dialog) {
         $("bgDialogDiv").show();
+
+	// Update callbacks on buttons
+	var buttons = dialog.getElementsByTagName("a");
+	buttons[0].stopObserving();
+	buttons[0].on("click", callbackYes);
+	buttons[1].stopObserving();
+	buttons[1].on("click", callbackNo || disposeDialog);
     }
     else {
         var fields = createElement("p");
@@ -1849,9 +1854,9 @@ function showConfirmDialog(title, label, callbackYes, callbackNo) {
                               fields,
                               "none");
         document.body.appendChild(dialog);
-        dialogs[title+label] = dialog;
+        dialogs[key] = dialog;
     }
-    dialog.show();
+    dialog.appear({ duration: 0.2 });
 }
 
 function showPromptDialog(title, label, callback, defaultValue) {
@@ -1872,7 +1877,7 @@ function showPromptDialog(title, label, callback, defaultValue) {
                                         _("OK"),
                                         callback.bind(input)));
 	fields.appendChild(createButton(null,
-                                        "Cancel",
+                                        _("Cancel"),
                                         disposeDialog));
         dialog = createDialog(null,
                               title,
@@ -1882,23 +1887,39 @@ function showPromptDialog(title, label, callback, defaultValue) {
         document.body.appendChild(dialog);
         dialogs[title+label] = dialog;
     }
-    dialog.show();
+    dialog.appear({ duration: 0.2 });
     dialog.down("input").focus();
 }
 
 function disposeDialog() {
     $$("DIV.dialog").each(function(div) {
-                              if (div.visible())
-                                  div.hide();
-                          });
-
+        if (div.visible() && div.getOpacity() == 1)
+            div.fade({ duration: 0.2 });
+    });
     if (dialogsStack.length > 0) {
+        // Show the next dialog box
         var label = dialogsStack.first();
         dialogsStack.splice(0, 1);
-        _showAlertDialog.delay(0.1, label);
+        _showAlertDialog.delay(0.2, label);
+    }
+    else {
+        var bgFade = Effect.Fade('bgDialogDiv', { duration: 0.2 });
+        // By the end the background fade out, a new dialog
+        // may need to be displayed.
+        _disposeDialog.delay(0.1, bgFade);
+    }
+}
+
+function _disposeDialog(bgEffect) {
+    if (dialogsStack.length) {
+        var div = $("bgDialogDiv");
+        bgEffect.cancel();
+        div.show();
+        div.appear({ duration: 0.2, to: 0.3 });
+        var label = dialogsStack.first();
+        dialogsStack.splice(0, 1);
+        _showAlertDialog(label);
     }
-    else
-        $("bgDialogDiv").hide();
 }
 
 function readCookie(name) {
